CONTRIBUTORS
============

- Fabrice Allain <https://github.com/f-allain>
- Jacob Marcel Anter <https://github.com/JacobAnter>
- Daniel Bauer <https://github.com/dnlbauer>
- Lukas Jarosch <https://github.com/ljarosch>
- Patrick Kunzmann <https://github.com/padix-key>
- Tom David Müller <https://github.com/t0mdavid-m>
- Thomas Nevolianis <https://github.com/thomasnevolianis>
- Maximilian Greil <https://github.com/MaxGreil>
- Claude J. Rogers <https://github.com/claudejrogers>
- Ivan Reveguk <https://github.com/edikedik>
- Jan H. Krumbach <https://github.com/JHKru>
- Danny P. Farrell <https://github.com/danpf>
- Daniel Ferrer Vinals <https://github.com/ferrervi>
- Jincai Yang <https://github.com/0ut0fcontrol>
- Tom Eulenfeld <https://github.com/trichter>
- Benjamin E. Mayer <https://github.com/entropybit>
- Natasha Jaffe <https://github.com/tcjaffe>
- Tristen J. Mier  <https://github.com/tjmier>